/*
 Copyright 2017 JetBrains s.r.o.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

/**
 * Module containing facilities to query YouTrack issues.
 *
 * @module @jetbrains/youtrack-scripting-api/search
 */

var Issue = require('./entities').Issue;

/**
 * Returns issues matching a query. In case no explicit sorting is specified, order of the resulting issues set should be
 * considered random.
 *
 * @example
 * var search = require('@jetbrains/youtrack-scripting-api/search');
 * ...
 * var query = 'for: me State: {In Progress} issue id: -' + issue.id;
 * var inProgress = search.search(issue.project, query, ctx.currentUser);
 * if (inProgress.isNotEmpty()) {
 *   // Do smth with a found set of issues.
 * }
 *
 * @param {WatchFolder} [folder] a project, an issue tag or a saved query to search in context of.
 * If omitted, all issues will be searched which is an equivalent to searching via UI with Everything set as a context.
 * @param {string} query YouTrack search query.
 * @param {User} [user] user to execute the query under. If not specified, current user will be taken.
 */
exports.search = function(folder, query, user) {
  if (typeof folder === 'string') {
    query = folder;
    folder = null;
  }
  return user ? Issue.search(folder, query, user) : Issue.search(folder, query);
};