/*
 Copyright 2017 JetBrains s.r.o.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

/**
 * Module containing utility functions.
 *
 * @module @jetbrains/youtrack-scripting-api/workflow
 */

var env = require('./environment');

/**
 * Displays a message on UI page.
 *
 * @param {string} [messageText] message text.
 */
exports.message = function (messageText) {
  env.message(messageText);
};

/**
 * Checks if the passed object is `true`, throws an error otherwise.
 * The error contains the message passed. The message is then shown to a user.
 *
 * @example
 * workflow.check(issue.fields.Assignee && ctx.currentUser.login === issue.fields.Assignee.login,
 *   'Only Assignee can mark issue as Fixed.');
 *
 * @param {boolean} [condition] condition to check.
 * @param {string} [message] error message that is shown to the user in case the condition is false.
 */
exports.check = function (condition, message) {
  env.checkCondition(!!condition, message);
};

/**
 * Returns a localized version of a message.
 * WARNING: for internal use only! This method is not intended to be used in custom workflows.
 *
 * @param {string} [messageId] message id.
 *
 * @returns {string} message with parameters filled.
 */
exports.localize = function (messageId, p1, p2, p3) {
  var params = [].slice.call(arguments);
  params.splice(0, 1);
  return env.localize(messageId, params);
};